Talks
=====

We are always interested in talking about :code:`pyhf`. See the abstract and a list of previously given presentations and feel free to invite us to your next conference/workshop/meeting!

Abstract
--------

    The HistFactory p.d.f. template `[CERN-OPEN-2012-016]
    <https://cds.cern.ch/record/1456844>`_ is per-se independent of its
    implementation in ROOT and it is useful to be able to run statistical
    analysis outside of the ROOT, RooFit, RooStats framework. pyhf is a
    pure-python implementation of that statistical model for multi-bin
    histogram-based analysis and its interval estimation is based on the
    asymptotic formulas of "Asymptotic formulae for likelihood-based tests of
    new physics" :xref:`arXiv:1007.1727`.  pyhf
    supports modern computational graph libraries such as TensorFlow and
    PyTorch in order to make use of features such as auto-differentiation and
    GPU acceleration.


    .. code-block:: latex

        The HistFactory p.d.f. template
        \href{https://cds.cern.ch/record/1456844}{[CERN-OPEN-2012-016]} is
        per-se independent of its implementation in ROOT and it is useful to be
        able to run statistical analysis outside of the ROOT, RooFit, RooStats
        framework. pyhf is a pure-python implementation of that statistical
        model for multi-bin histogram-based analysis and its interval
        estimation is based on the asymptotic formulas of "Asymptotic formulae
        for likelihood-based tests of new physics"
        \href{https://arxiv.org/abs/1007.1727}{[arXiv:1007.1727]}. pyhf
        supports modern computational graph libraries such as TensorFlow and
        PyTorch in order to make use of features such as autodifferentiation
        and GPU acceleration.


Presentations
-------------

This list will be updated with talks given on :code:`pyhf`:

.. bibliography:: bib/talks.bib
   :list: bullet
   :all:
   :style: plain

Tutorials
---------

This list will be updated with tutorials and schools given on :code:`pyhf`:

.. bibliography:: bib/tutorials.bib
   :list: bullet
   :all:
   :style: plain


Posters
-------

This list will be updated with posters presented on :code:`pyhf`:

.. bibliography:: bib/posters.bib
   :list: bullet
   :all:
   :style: plain
